@@ -6,7 +6,7 @@ use warnings;
 use strict;
 
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 
 use base 'Class::Value::Exception';
@@ -22,7 +22,7 @@ __END__
 
 =head1 NAME
 
-Class::Value - foobar
+Class::Value - the Value Object design pattern
 
 =head1 SYNOPSIS
 
